#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from __future__ import print_function

import subprocess

from systemd import journal

ifGenStream = journal.stream(identifier='if_gen')


class if_gen(object):
    def __init__(self, name=None, if_cfg_dict=None):
        self.name = name
        self.cfg_dict = {}

        if if_cfg_dict is not None and isinstance(if_cfg_dict, dict):
            self.name = if_cfg_dict.get("name", None)
            self.init_by_dict(if_cfg_dict)

    def __eq__(self, other):
        if isinstance(self, other.__class__):
            return self.__dict__ == other.__dict__

        return False

    def __ne__(self, other):
        return not self.__eq__(other)

    def init_by_dict(self, if_cfg):
        self.cfg_dict['name'] = self.name
        self.cfg_dict['enable'] = if_cfg.get('enable', False)
        self.cfg_dict['bootproto'] = if_cfg.get('bootproto', 'none')
        self.cfg_dict['ipv4-address'] = if_cfg.get('ipv4-address', '')
        self.cfg_dict['netmask'] = if_cfg.get('netmask', '')

    def write_ifcfg(self, fname=None):
        createNatString = ['/scripts/apply_networking.py', "-n%s" % self.name]

        onboot = 'yes' if self.cfg_dict['enable'] else 'no'
        createNatString += ["-o%s" % onboot]
        if self.cfg_dict['bootproto'] and 'dhcp' == self.cfg_dict['bootproto']:
            createNatString += ['-bdhcp']
        if self.cfg_dict['ipv4-address']:
            createNatString += ['-a%s' % self.cfg_dict['ipv4-address']]
        if self.cfg_dict['netmask']:
            createNatString += ['-m%s' % self.cfg_dict['netmask']]

        try:
            subprocess.check_call(createNatString)
        except subprocess.CalledProcessError as e:
            print('Command \"%s\" failed with code %d' % (e.cmd, e.returncode), file=ifGenStream)
        except OSError as e:
            print('System error - \"%s\"' % e.strerror, file=ifGenStream)

    def remove_ifcfg(self, fname=None):
        try:
            subprocess.check_call(['/scripts/apply_networking.py', "-z%s" % self.name])
        except subprocess.CalledProcessError as e:
            print('Command \"%s\" failed with code %d' % (e.cmd, e.returncode), file=ifGenStream)
        except OSError as e:
            print('System error - \"%s\"' % e.strerror, file=ifGenStream)

    def is_enabled(self):
        return self.cfg_dict['enable']
