#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from __future__ import print_function

import os
import subprocess

from netaddr import *
from systemd import journal
from tveif import if_eth

ifMgmtStream = journal.stream(identifier='if_mgmt')
sysrepo_file = "/config/_sysrepo"


class if_mgmt(if_eth.if_eth):
    def __init__(self, if_cfg=None):
        self.name = None
        self.ipv4addr = None
        super(if_mgmt, self).__init__(self.name, if_cfg)
        self.dpdk_mode = None

        if if_cfg is not None:
            if os.path.exists(sysrepo_file):
                ipv4addr = if_cfg.get('ipv4-prefix', '')
                if '' == ipv4addr:
                    self.bootproto = 'manual'
                else:
                    self.bootproto = 'static'
                    ip = IPNetwork(ipv4addr)
                    self.ipv4addr = str(ip.ip)
            else:
                ipv4addr = if_cfg.get('ipv4-address', '')
                if '' == ipv4addr:
                    self.bootproto = 'manual'
                else:
                    self.bootproto = 'static'
                    self.ipv4addr = ipv4addr

    def get_name(self):
        if self.name is None:
            return "NONE"
        else:
            return self.name

    def create(self, dpdk=False):
        self.dpdk_mode = dpdk

        try:
            subprocess.check_call(['/usr/bin/ovs-vsctl', 'add-br', self.name])
        except subprocess.CalledProcessError as e:
            print('Command \"%s\" failed with code %d' % (e.cmd, e.returncode), file=ifMgmtStream)

        self.write_ifcfg()

    def clean_mgmt(self):
        try:
            subprocess.check_call(['/sbin/ip', 'address', 'flush', self.name])
        except subprocess.CalledProcessError:
            print('Cannot flush interface %s' % self.name)
        except OSError:
            print('\'ip\' not found')

    def write_ifcfg(self, fname=None):
        createBridgeIfString = [
            "/scripts/apply_networking.py",
            "-n%s" % self.name,
            "-b%s" % self.bootproto,
            "--ovs-master", "ovs"]
        if None != self.ipv4addr:
            createBridgeIfString += ["-a%s" % self.ipv4addr]

        try:
            subprocess.check_call(createBridgeIfString)
        except subprocess.CalledProcessError as e:
            print("Command \"%s\" failed with code %d" % (e.cmd, e.returncode), file=ifMgmtStream)
        except OSError as e:
            print('System error - \"%s\"' % e.strerror, file=ifNatStream)

    def delete(self):
        subprocess.check_call(['/sbin/ifdown', self.name])
        if self.cfg_fname is not None:
            os.remove(self.cfg_fname)

        subprocess.check_call(['/usr/bin/ovs-vsctl', 'del-br', self.name])
